from random import choice
if not __name__ == '__main__':
	amuesmmodule = []
	amuesmmodule2 = []
	amuesmmodule3 = ['']
	def createpass(charset, len):
		amuesmmodule.clear()
		for _ in range(len):
			amuesmmodule.append(choice(charset))
		return ''.join(amuesmmodule)
		amuesmmodule.clear()
	def en(str, charset):
		amuesmmodule.clear()
		amuesmmodule2.clear()
		for char in str:
			for _ in range(charset.index(char) + 1):
				amuesmmodule2.append('-')
			amuesmmodule.append(''.join(amuesmmodule2))
			amuesmmodule2.clear()
		return ' '.join(amuesmmodule)
		amuesmmodule.clear()
	def de(str, charset):
		amuesmmodule.clear()
		global amuesmmodule3
		amuesmmodule3.clear()
		amuesmmodule3 = str.split(' ')
		for encline in amuesmmodule3:
			amuesmmodule.append(charset[len(encline) - 1])
		amuesmmodule3.clear()
		return ''.join(amuesmmodule)
		amuesmmodule.clear()
	def amuesmcredits():
		print('Created with amuesm Developed by AnniePrograms! Download at https://pypi.org/project/amuesm/')



import amuesm
from os import system
def main():
	system('clear')
	print('Welcome to amuesm!\n')
	def selop():
		try:
			global opt
			opt = int(input('''Enter an Index Below:
1. Generate Password
2. Encode Text (amuesm-based)
3. Decode Text (amuesm-based)
>> '''))
		except TypeError:
			print('Not a Valid Index!')
			selop()
	selop()
	system('clear')
	if opt == 1:
		charset = str(input('''Enter All Characters to Support
>> '''))
		def selplen():
			global leng
			try:
				leng = int(input('''Enter Password Length
>> '''))
			except TypeError:
				print('Not a Valid Number!')
		selplen()
		print(amuesm.createpass(list(charset), leng))
	elif opt == 2:
		charset = str(input('''Enter All Characters to Support
>> '''))
		txt = str(input('''Enter Text to Encode
>> '''))
		print(amuesm.en(txt, list(charset)))
	else:
	        charset = str(input('''Enter All Characters to Support
>> '''))
	        txt = str(input('''Enter Text to Decode
>> '''))
	        print(amuesm.de(txt, list(charset)))
if __name__ == '__main__':
	main()
